==> libreoffice-still-sdk-25.2.7-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/TemplateDescription_8idl.js <==
var TemplateDescription_8idl =
[
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PLAY", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#acdf1d0c7effc160cf0e550167f375198", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a8d13043b5e73ee5556bacdbb74124d9d", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW_IMAGE_ANCHOR", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a60c10b422214b1a012381df49ba84cf3", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW_IMAGE_TEMPLATE", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a8531f432085caae85b738943ad25bee1", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_PLAY", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a1b4ea5d7f911e01369f98304a393c1de", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_PREVIEW", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#aa12a0984efee63fcffa77d0a9a6e86c7", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_READONLY_VERSION", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a85a179ce22a22c5fd437b99cd6292fe6", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#abd22bd8de4497ac68b5950779a5b6788", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a723246fd7bdf7bf3354dfe7425f39f94", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#aa7369395ca1b8b632a059baabe218212", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD_FILTEROPTIONS", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a22e7be400c620c2c71dd96c0e0640103", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_SELECTION", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a7c8f1755c932ff3c771e0a6599fad0b8", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_TEMPLATE", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#ae286382add62890546b640054b582697", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_SIMPLE", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a411ab07adc4e47fceecba27c06fc8d9d", null ]
];

==> libreoffice-still-sdk-25.8.5-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/TemplateDescription_8idl.js <==
var TemplateDescription_8idl =
[
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PLAY", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#acdf1d0c7effc160cf0e550167f375198", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a8d13043b5e73ee5556bacdbb74124d9d", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW_IMAGE_ANCHOR", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a60c10b422214b1a012381df49ba84cf3", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW_IMAGE_TEMPLATE", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a8531f432085caae85b738943ad25bee1", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_PLAY", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a1b4ea5d7f911e01369f98304a393c1de", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_PREVIEW", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#aa12a0984efee63fcffa77d0a9a6e86c7", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_READONLY_VERSION", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a85a179ce22a22c5fd437b99cd6292fe6", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_READONLY_VERSION_FILTEROPTIONS", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#abc9b3950d0450f3c01b4f27e595bd28d", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#abd22bd8de4497ac68b5950779a5b6788", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a723246fd7bdf7bf3354dfe7425f39f94", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#aa7369395ca1b8b632a059baabe218212", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD_FILTEROPTIONS", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a22e7be400c620c2c71dd96c0e0640103", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_SELECTION", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a7c8f1755c932ff3c771e0a6599fad0b8", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_TEMPLATE", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#ae286382add62890546b640054b582697", null ],
    [ "com::sun::star::ui::dialogs::TemplateDescription::FILESAVE_SIMPLE", "namespacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1TemplateDescription.html#a411ab07adc4e47fceecba27c06fc8d9d", null ]
];
